@@ -19,9 +19,7 @@ class AppInitCommand(CliCommand):
         pass
 
     def run(self, args):
-        print('This command is not fully implemented yet.')
-        print('For now, it will just git clone a C++ app template repository')
-        print('')
-        answer = input('> Clone app template repository into \'app-template-cpp\' folder? (yes, No)')
-        if answer == 'yes':
-            subprocess.run(['git', 'clone', 'git@github.com:Auterion/app-template-cpp.git'])
+        print("To start writing apps for AuterionOS, join the Auterion developer program.")
+        print("You can get more resources on suite.auterion.com")
+        print("Documentation: https://docs.auterion.com/")
+
