@@ -110,7 +110,14 @@ def check_for_updates(persistent_state):
     persistent_state['last_update_check_time'] = int(current_time)
 
     print('Checking for updates...')
-    res = requests.get('https://pypi.org/pypi/auterion-cli/json')
+    try:
+        res = requests.get('https://pypi.org/pypi/auterion-cli/json', timeout=1)
+    except requests.exceptions.Timeout:
+        eprint("Warning: Update check timed out")
+        return
+    except:
+        eprint("Warning: Update check failed")
+        return
     if res.ok:
         data = res.json()
         up_version = data.get('info', {}).get('version', None)
@@ -120,7 +127,7 @@ def check_for_updates(persistent_state):
             if version.parse(up_version) > version.parse(our_version):
                 print("  ┌──────────────────────────────────────────────────────────────────────────────────────┐")
                 print("  │                                                                                      │")
-                print("  │  A new version of auterion-cli is available!   {:>16} -> {:<16}  │".format(
+                print("  │  A new version of auterion-cli is available! {:>20} -> {:<16}│".format(
                     our_version, up_version))
                 print("  │                                                                                      │")
                 print("  │  Run `pip install --upgrade auterion-cli` to upgrade.                                │")
